@@ -2,9 +2,9 @@ from enum import IntEnum
 from functools import partial
 from typing import Any
 
-from ..qtcompat.QtCore import QPoint, QSize, Qt, Signal
-from ..qtcompat.QtGui import QFontMetrics, QValidator
-from ..qtcompat.QtWidgets import (
+from qtpy.QtCore import QPoint, QSize, Qt, Signal
+from qtpy.QtGui import QFontMetrics, QValidator
+from qtpy.QtWidgets import (
     QAbstractSlider,
     QApplication,
     QDoubleSpinBox,
@@ -16,6 +16,7 @@ from ..qtcompat.QtWidgets import (
     QVBoxLayout,
     QWidget,
 )
+
 from ._sliders import QDoubleRangeSlider, QDoubleSlider, QRangeSlider
 
 
@@ -117,6 +118,7 @@ def _handle_overloaded_slider_sig(args, kwargs):
 
 
 class QLabeledSlider(_SliderProxy, QAbstractSlider):
+    EdgeLabelMode = EdgeLabelMode
     _slider_class = QSlider
     _slider: QSlider
 
@@ -127,16 +129,27 @@ class QLabeledSlider(_SliderProxy, QAbstractSlider):
 
         self._slider = self._slider_class()
         self._label = SliderLabel(self._slider, connect=self._slider.setValue)
+        self._edge_label_mode: EdgeLabelMode = EdgeLabelMode.LabelIsValue
 
+        self._rename_signals()
+        self._slider.actionTriggered.connect(self.actionTriggered.emit)
         self._slider.rangeChanged.connect(self.rangeChanged.emit)
+        self._slider.sliderMoved.connect(self.sliderMoved.emit)
+        self._slider.sliderPressed.connect(self.sliderPressed.emit)
+        self._slider.sliderReleased.connect(self.sliderReleased.emit)
         self._slider.valueChanged.connect(self.valueChanged.emit)
         self._slider.valueChanged.connect(self._label.setValue)
 
         self.setOrientation(orientation)
 
+    def _rename_signals(self):
+        # for subclasses
+        pass
+
     def setOrientation(self, orientation):
         """Set orientation, value will be 'horizontal' or 'vertical'."""
         self._slider.setOrientation(orientation)
+        marg = (0, 0, 0, 0)
         if orientation == Qt.Orientation.Vertical:
             layout = QVBoxLayout()
             layout.addWidget(self._slider, alignment=Qt.AlignmentFlag.AlignHCenter)
@@ -144,6 +157,9 @@ class QLabeledSlider(_SliderProxy, QAbstractSlider):
             self._label.setAlignment(Qt.AlignmentFlag.AlignCenter)
             layout.setSpacing(1)
         else:
+            if self._edge_label_mode == EdgeLabelMode.NoLabel:
+                marg = (0, 0, 5, 0)
+
             layout = QHBoxLayout()
             layout.addWidget(self._slider)
             layout.addWidget(self._label)
@@ -154,20 +170,50 @@ class QLabeledSlider(_SliderProxy, QAbstractSlider):
         if old_layout is not None:
             QWidget().setLayout(old_layout)
 
-        layout.setContentsMargins(0, 0, 0, 0)
+        layout.setContentsMargins(*marg)
         self.setLayout(layout)
 
+    def edgeLabelMode(self) -> EdgeLabelMode:
+        return self._edge_label_mode
+
+    def setEdgeLabelMode(self, opt: EdgeLabelMode) -> None:
+        if opt is EdgeLabelMode.LabelIsRange:
+            raise ValueError(
+                "mode must be one of 'EdgeLabelMode.NoLabel' or "
+                "'EdgeLabelMode.LabelIsValue'."
+            )
+
+        self._edge_label_mode = opt
+        if not self._edge_label_mode:
+            self._label.hide()
+            w = 5 if self.orientation() == Qt.Orientation.Horizontal else 0
+            self.layout().setContentsMargins(0, 0, w, 0)
+        else:
+            if self.isVisible():
+                self._label.show()
+            self._label.setMode(opt)
+            self._label.setValue(self._slider.value())
+            self.layout().setContentsMargins(0, 0, 0, 0)
+
+        QApplication.processEvents()
+
 
 class QLabeledDoubleSlider(QLabeledSlider):
     _slider_class = QDoubleSlider
     _slider: QDoubleSlider
-    valueChanged = Signal(float)
-    rangeChanged = Signal(float, float)
+    _fvalueChanged = Signal(float)
+    _fsliderMoved = Signal(float)
+    _frangeChanged = Signal(float, float)
 
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.setDecimals(2)
 
+    def _rename_signals(self):
+        self.valueChanged = self._fvalueChanged
+        self.sliderMoved = self._fsliderMoved
+        self.rangeChanged = self._frangeChanged
+
     def decimals(self) -> int:
         return self._label.decimals()
 
@@ -176,7 +222,7 @@ class QLabeledDoubleSlider(QLabeledSlider):
 
 
 class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
-    valueChanged = Signal(tuple)
+    _valueChanged = Signal(tuple)
     LabelPosition = LabelPosition
     EdgeLabelMode = EdgeLabelMode
     _slider_class = QRangeSlider
@@ -185,6 +231,8 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
     def __init__(self, *args, **kwargs) -> None:
         parent, orientation = _handle_overloaded_slider_sig(args, kwargs)
         super().__init__(parent)
+        self._rename_signals()
+
         self.setAttribute(Qt.WidgetAttribute.WA_ShowWithoutActivating)
         self._handle_labels = []
         self._handle_label_position: LabelPosition = LabelPosition.LabelsAbove
@@ -216,6 +264,9 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
         self._on_range_changed(self._slider.minimum(), self._slider.maximum())
         self.setOrientation(orientation)
 
+    def _rename_signals(self):
+        self.valueChanged = self._valueChanged
+
     def handleLabelPosition(self) -> LabelPosition:
         return self._handle_label_position
 
@@ -392,12 +443,16 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
 class QLabeledDoubleRangeSlider(QLabeledRangeSlider):
     _slider_class = QDoubleRangeSlider
     _slider: QDoubleRangeSlider
-    rangeChanged = Signal(float, float)
+    _frangeChanged = Signal(float, float)
 
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.setDecimals(2)
 
+    def _rename_signals(self):
+        super()._rename_signals()
+        self.rangeChanged = self._frangeChanged
+
     def decimals(self) -> int:
         return self._min_label.decimals()
 
@@ -462,7 +517,7 @@ class SliderLabel(QDoubleSpinBox):
         )
         self.setFixedSize(size)
 
-    def setValue(self, val):
+    def setValue(self, val: Any) -> None:
         super().setValue(val)
         if self._mode == EdgeLabelMode.LabelIsRange:
             self._update_size()
