@@ -5,17 +5,20 @@ __all__ = (
     "FunctionWorker",
     "GeneratorWorker",
     "new_worker_qthread",
-    "QMessageHandler",
-    "thread_worker",
-    "WorkerBase",
-    "qthrottled",
     "qdebounced",
+    "QMessageHandler",
     "QSignalDebouncer",
     "QSignalThrottler",
+    "qthrottled",
+    "signals_blocked",
+    "thread_worker",
+    "WorkerBase",
 )
 
+
 from ._ensure_thread import ensure_main_thread, ensure_object_thread
 from ._message_handler import QMessageHandler
+from ._misc import signals_blocked
 from ._qthreading import (
     FunctionWorker,
     GeneratorWorker,
